.no-dizmo-drag {
    -apple-dashboard-region: dashboard-region(control rectangle);
}

body {
    margin: 0px;
    padding: 0px;
}

#front {
    width: 100%;

    .center {
        margin-left: auto;
        margin-right: auto;
        width: 112px;
        margin-top: 50px;

        p {
            font-size: 20px;
            font-weight: bold;
            color: white;
        }
    }
}

#back {
    .done-btn-wrapper {
        position: absolute;
        bottom: 0px;
        left: 0px;
        width: 100%;

        .done-btn {
            margin-bottom: 20px;
        }
    }
}
