@import url("themes/light/light.css");@import url("themes/dark/dark.css");html{font-family:"Pharma"}button.dizmo-button{display:block;outline:none;font-size:12px;font-family:"Pharma";font-weight:bold;text-transform:uppercase;background:none;width:80px;height:30px;padding:0;border-radius:10px}.dizmo-checkbox .dizmo-checkbox-input{display:none}.dizmo-checkbox .dizmo-checkbox-label{font-family:"Pharma";cursor:pointer;vertical-align:middle}.dizmo-checkbox .dizmo-checkbox-label span{display:inline-block;vertical-align:middle}.dizmo-checkbox .dizmo-checkbox-label span.dizmo-checkbox-label-image{margin-right:10px;width:25px;height:25px}.dizmo-selectbox{height:48px;position:relative;border-radius:10px;font-size:16px}.dizmo-selectbox span.dizmo-selectbox-text{line-height:48px;text-indent:10px;display:inline-block;font-family:"Pharma";font-weight:bold}.dizmo-selectbox span.dizmo-selectbox-image{position:absolute;top:20px;right:10px;height:15px;width:15px}.dizmo-selectbox ul.dizmo-selectbox-list{padding:0;margin:0;list-style-type:none;position:absolute;z-index:1000;left:-1px;border-bottom-right-radius:10px;border-bottom-left-radius:10px}.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry{text-indent:10px;padding-top:10px;padding-bottom:10px;font-family:"Pharma"}.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:first-child{margin-top:10px}.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:last-child{margin-bottom:10px}.dizmo-selectbox-open{border-bottom-right-radius:0;border-bottom-left-radius:0}.dizmo-slider{padding:25px;border-radius:10px}.dizmo-slider .dizmo-slider-inner{background-image:none;background-repeat-x:initial;background-repeat-y:initial;background-attachment:initial;background-position-x:initial;background-position-y:initial;background-origin:initial;background-clip:initial;border:none;width:100%;-apple-dashboard-region:dashboard-region(control rectangle)}.dizmo-slider .dizmo-slider-inner a.ui-slider-handle{border:none;width:20px;height:20px;outline:none;-apple-dashboard-region:dashboard-region(control rectangle)}.dizmo-slider.orientation-horizontal{height:2px}.dizmo-slider.orientation-horizontal .dizmo-slider-inner{height:2px}.dizmo-slider.orientation-horizontal .dizmo-slider-inner a.ui-slider-handle{top:-9px}.dizmo-slider.orientation-vertical{width:2px}.dizmo-slider.orientation-vertical .dizmo-slider-inner{width:2px}.dizmo-slider.orientation-vertical .dizmo-slider-inner a.ui-slider-handle{left:-9px}button.dizmo-switch{outline:none;padding:0;position:relative;border-radius:10px}button.dizmo-switch span.dizmo-switch-box{width:50%;height:100%;display:inline-block;position:absolute;top:-1px;background-repeat:no-repeat;border-radius:10px}button.dizmo-switch span.dizmo-switch-off-box{background-color:#d04048}button.dizmo-switch span.dizmo-switch-on-box{background-color:#afc819}