button.dizmo-button-light{border:1px solid #ededed;background-color:#3c3c3c;color:#ededed}button.dizmo-button-light:active{border:1px solid #3c3c3c;background-color:#ededed;color:#3c3c3c}.dizmo-checkbox-light .dizmo-checkbox-input:checked+.dizmo-checkbox-label span.dizmo-checkbox-label-image{background:url('images/checkbox/unchecked.svg') left top no-repeat}.dizmo-checkbox-light .dizmo-checkbox-label{color:#ededed}.dizmo-checkbox-light .dizmo-checkbox-label span.dizmo-checkbox-label-image{background:url('images/checkbox/checked.svg') left top no-repeat}.dizmo-selectbox-light{background-color:#ededed;border:1px solid #3c3c3c}.dizmo-selectbox-light span.dizmo-selectbox-text{color:#3c3c3c}.dizmo-selectbox-light span.dizmo-selectbox-image{background:url('images/selectbox/arrow_down.svg') 0 0 no-repeat}.dizmo-selectbox-light ul.dizmo-selectbox-list{background-color:#ededed;border:1px solid #3c3c3c}.dizmo-selectbox-light ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry{color:#3c3c3c}.dizmo-selectbox-light ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:hover{color:#ededed;background-color:#3c3c3c}.dizmo-selectbox-light.dizmo-selectbox-open span.dizmo-selectbox-image{background:url('images/selectbox/arrow_up.svg') 0 0 no-repeat}.dizmo-slider-light{border:1px solid #ededed}.dizmo-slider-light .dizmo-slider-inner{background-color:#ededed}.dizmo-slider-light .dizmo-slider-inner a.ui-slider-handle{background:url('images/slider/handle.svg') no-repeat}button.dizmo-switch-light{background-color:#ededed;border:1px solid #3c3c3c}button.dizmo-switch-light span.dizmo-switch-box{color:#ededed;border:1px solid #3c3c3c}button.dizmo-switch-light span.dizmo-switch-on-box{border-left:1px solid #3c3c3c}button.dizmo-switch-light span.dizmo-switch-off-box{border-right:1px solid #3c3c3c}