@import url("themes/light/light.css");@import url("themes/dark/dark.css");html{font-family:"Pharma-Regular","Pharma Regular",sans-serif}input.dizmo-input{border:none;border-radius:5px;margin:0;padding:5px;font-size:16px;outline:none;-apple-dashboard-region:dashboard-region(control rectangle);font-family:"Pharma-Regular","Pharma Regular",sans-serif}textarea.dizmo-textarea{border:none;outline:none;border-radius:5px;padding:5px;font-size:16px;margin:0;resize:none;-apple-dashboard-region:dashboard-region(control rectangle);font-family:"Pharma-Regular","Pharma Regular",sans-serif}button.dizmo-button{display:inline-block;outline:none;font-size:12px;font-family:"Pharma-Bold","Pharma Bold",sans-serif;font-weight:bold;text-transform:uppercase;width:80px;height:30px;padding:0;border-radius:10px}.dizmo-checkbox .dizmo-checkbox-input{display:none}.dizmo-checkbox .dizmo-checkbox-label{font-family:"Pharma-Regular","Pharma Regular",sans-serif;cursor:pointer;vertical-align:middle}.dizmo-checkbox .dizmo-checkbox-label span{display:inline-block;vertical-align:middle}.dizmo-checkbox .dizmo-checkbox-label span.dizmo-checkbox-label-image{margin-right:10px;width:25px;height:25px}.dizmo-checkbox.disabled .dizmo-checkbox-label{color:#b4b4b4}.dizmo-selectbox{height:48px;position:relative;border-radius:10px;font-size:16px;display:inline-block}.dizmo-selectbox span.dizmo-selectbox-text{line-height:48px;text-indent:10px;display:inline-block;font-family:"Pharma-Bold","Pharma Bold",sans-serif;font-weight:bold}.dizmo-selectbox span.dizmo-selectbox-image{position:absolute;top:20px;right:10px;height:15px;width:15px}.dizmo-selectbox ul.dizmo-selectbox-list{padding:0;margin:0;list-style-type:none;position:absolute;z-index:1000;left:-1px}.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry{text-indent:5px;margin-left:5px;margin-right:5px;padding-top:10px;padding-bottom:10px;font-family:"Pharma-Regular","Pharma Regular",sans-serif}.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:first-child{margin-top:10px}.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:last-child{margin-bottom:10px}.dizmo-selectbox-open-down{border-bottom-right-radius:0;border-bottom-left-radius:0}.dizmo-selectbox-open-down ul.dizmo-selectbox-list{border-bottom-right-radius:10px;border-bottom-left-radius:10px}.dizmo-selectbox-open-up{border-top-right-radius:0;border-top-left-radius:0}.dizmo-selectbox-open-up ul.dizmo-selectbox-list{border-top-right-radius:10px;border-top-left-radius:10px}.dizmo-slider{position:relative;border-radius:2px;-apple-dashboard-region:dashboard-region(control rectangle)}.dizmo-slider .dizmo-slider-inner{position:absolute;-apple-dashboard-region:dashboard-region(control rectangle)}.dizmo-slider .dizmo-slider-inner .dizmo-slider-handle{position:absolute;-apple-dashboard-region:dashboard-region(control rectangle);height:20px;width:20px;border-radius:100%}.dizmo-slider .dizmo-slider-inner .dizmo-slider-handle .dizmo-slider-handle-text{text-align:center;display:block}.dizmo-slider-horizontal{height:2px}.dizmo-slider-vertical{width:2px}button.dizmo-switch{outline:none;padding:0;position:relative;border-radius:10px;font-family:"Pharma-Regular","Pharma Regular",sans-serif}button.dizmo-switch span.dizmo-switch-box{width:50%;height:100%;display:inline-block;position:absolute;top:-1px;background-repeat:no-repeat;border-radius:10px}button.dizmo-switch span.dizmo-switch-off-box{background-color:#d04048}button.dizmo-switch span.dizmo-switch-on-box{background-color:#afc819}.dizmo-colorwheel{-apple-dashboard-region:dashboard-region(control rectangle);border-radius:100%;position:relative;border:1px solid #3c3c3c}.dizmo-colorwheel .wheel{background-image:url('images/colorwheel.png');top:0;left:0;position:absolute;z-index:10}.dizmo-colorwheel .value-overlay{top:0;left:0;position:absolute;z-index:20}.dizmo-colorwheel .pointer{position:absolute;z-index:30;width:8px;height:8px;border-radius:100%}