input.dizmo-input-dark{background:none;background-color:#3c3c3c;color:#ededed}input.dizmo-input.disabled{background-color:#a0a0a0}textarea.dizmo-textarea-dark{background:none;background-color:#3c3c3c;color:#ededed}textarea.dizmo-textarea.disabled{background-color:#a0a0a0}button.dizmo-button-dark{border:1px solid #3c3c3c;background-color:#3c3c3c;color:#ededed}button.dizmo-button-dark:active{border:1px solid #3c3c3c;background-color:#ededed;color:#3c3c3c}button.dizmo-button.disabled{background-color:#a0a0a0}.dizmo-checkbox-dark .dizmo-checkbox-input:checked+.dizmo-checkbox-label span.dizmo-checkbox-label-image{background:url("images/checkbox/unchecked.svg") left top no-repeat}.dizmo-checkbox-dark .dizmo-checkbox-label{color:#3c3c3c}.dizmo-checkbox-dark .dizmo-checkbox-label span.dizmo-checkbox-label-image{background:url("images/checkbox/checked.svg") left top no-repeat}.dizmo-selectbox-dark{background-color:#3c3c3c;border:1px solid #ededed}.dizmo-selectbox-dark span.dizmo-selectbox-text{color:#ededed}.dizmo-selectbox-dark span.dizmo-selectbox-image{background:url("images/selectbox/arrow_down.svg") 0 0 no-repeat}.dizmo-selectbox-dark ul.dizmo-selectbox-list{background-color:#3c3c3c;border:1px solid #ededed}.dizmo-selectbox-dark ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry{color:#ededed;border-bottom:1px solid #ededed}.dizmo-selectbox-dark ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:last-child{border-bottom:none}.dizmo-selectbox-dark ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:hover{color:#3c3c3c;background-color:#ededed}.dizmo-selectbox-dark.disabled{background-color:#a0a0a0}.dizmo-selectbox-dark.disabled span.dizmo-selectbox-image{background:url("images/selectbox/arrow_down_disabled.svg") 0 0 no-repeat}.dizmo-selectbox-dark.dizmo-selectbox-open-up span.dizmo-selectbox-image,.dizmo-selectbox-dark.dizmo-selectbox-open-down span.dizmo-selectbox-image{background:url("images/selectbox/arrow_up.svg") 0 0 no-repeat}.dizmo-slider-dark{background-color:#3c3c3c}.dizmo-slider-dark .dizmo-slider-inner .dizmo-slider-handle{background-color:#3c3c3c}.dizmo-slider-dark .dizmo-slider-inner .dizmo-slider-handle .dizmo-slider-handle-text{color:#ededed}button.dizmo-switch-dark{background-color:#3c3c3c;border:1px solid #ededed}button.dizmo-switch-dark span.dizmo-switch-box{color:#3c3c3c;border:1px solid #ededed}button.dizmo-switch-dark span.dizmo-switch-on-box{border-left:1px solid #ededed}button.dizmo-switch-dark span.dizmo-switch-off-box{border-right:1px solid #ededed}